@@ -1,5 +1,5 @@
-/* Copyright (C) 2000-2004 Boris Wesslowski */
-/* $Id: main.c,v 1.112 2004/03/28 18:53:02 bw Exp $ */
+/* Copyright (C) 2000-2006 Boris Wesslowski */
+/* $Id: main.c,v 1.115 2006/03/08 19:36:03 bw Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -85,7 +85,7 @@ void info()
 {
   /* GNU standards compatible program info */
   printf("%s %s\n", PACKAGE, VERSION);
-  puts("Copyright (C) 2000-2004 Boris Wesslowski");
+  puts("Copyright (C) 2000-2006 Boris Wesslowski");
   puts("");
   puts("This program is free software; you can redistribute it and/or modify");
   puts("it under the terms of the GNU General Public License as published by");
@@ -128,6 +128,12 @@ void info()
 #else
   puts(_("disabled"));
 #endif
+  printf(_("GNU adns support "));
+#ifdef HAVE_ADNS
+  puts(_("enabled"));
+#else
+  puts(_("disabled"));
+#endif
 
   exit(EXIT_SUCCESS);
 }
