@@ -1,5 +1,5 @@
-/* Copyright (C) 2000-2004 Boris Wesslowski */
-/* $Id: response.c,v 1.46 2004/03/21 09:42:55 bw Exp $ */
+/* Copyright (C) 2000-2006 Boris Wesslowski */
+/* $Id: response.c,v 1.49 2006/03/08 19:36:03 bw Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -415,8 +415,3 @@ struct known_hosts *fwlw_hs_mergesort(struct known_hosts *list) {
     return list;
   }
 }
-
-void sort_hs()
-{
-  first_host = fwlw_hs_mergesort(first_host);
-}
