@@ -1,5 +1,5 @@
-/* Copyright (C) 2000-2004 Boris Wesslowski */
-/* $Id: response.h,v 1.11 2004/03/21 09:42:55 bw Exp $ */
+/* Copyright (C) 2000-2006 Boris Wesslowski */
+/* $Id: response.h,v 1.14 2006/03/08 19:36:03 bw Exp $ */
 
 #ifndef _RESPONSE_H
 #define _RESPONSE_H
@@ -12,6 +12,6 @@ void check_script_perms(char *name);
 void modify_firewall(unsigned char action);
 void remove_old(unsigned char mode);
 void look_for_alert(void);
-void sort_hs(void);
+struct known_hosts *fwlw_hs_mergesort(struct known_hosts *list);
 
 #endif
